==> activity-center-api-0.10.27sjq-20191129.021611-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/AdvertisingSpaceStyleDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.List;

/**
 * @author shenjiaqing
 * @description
 * @data 2019/11/20
 */
public class AdvertisingSpaceStyleDto implements Serializable {

    /** 样式ID **/
    private Long id;

    /** 广告位类型ID **/
    private Long adTypeId;

    /** 样式名称 **/
    private String adStyleName;

    /** 最少标题字数 **/
    private Integer titleMinNum;

    /** 最多标题字数 **/
    private Integer titleMaxNum;

    /** 最少描述字数 **/
    private Integer descriptionMinNum;

    /** 最多描述字数 **/
    private Integer descriptionMaxNum;

    /** ADX样式ID **/
    private String templateId;

    /** 素材数量 **/
    private Integer num;

    /** 创建时间 **/
    private String createTime;

    /** 广告位样式ID **/
    private Long adStyleId;

    /** 素材类型 **/
    private Integer type;

    /** 素材宽度 **/
    private Integer width;

    /** 素材高度 **/
    private Integer height;

    /** 素材大小 **/
    private Integer size;

    /** 素材单位 **/
    private String unit;

    /** 素材格式 **/
    private String format;

    /** 视频时长 **/
    private Integer duration;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdTypeId() {
        return adTypeId;
    }

    public void setAdTypeId(Long adTypeId) {
        this.adTypeId = adTypeId;
    }

    public String getAdStyleName() {
        return adStyleName;
    }

    public void setAdStyleName(String adStyleName) {
        this.adStyleName = adStyleName;
    }

    public Integer getTitleMinNum() {
        return titleMinNum;
    }

    public void setTitleMinNum(Integer titleMinNum) {
        this.titleMinNum = titleMinNum;
    }

    public Integer getTitleMaxNum() {
        return titleMaxNum;
    }

    public void setTitleMaxNum(Integer titleMaxNum) {
        this.titleMaxNum = titleMaxNum;
    }

    public Integer getDescriptionMinNum() {
        return descriptionMinNum;
    }

    public void setDescriptionMinNum(Integer descriptionMinNum) {
        this.descriptionMinNum = descriptionMinNum;
    }

    public Integer getDescriptionMaxNum() {
        return descriptionMaxNum;
    }

    public void setDescriptionMaxNum(Integer descriptionMaxNum) {
        this.descriptionMaxNum = descriptionMaxNum;
    }

    public String getTemplateId() {
        return templateId;
    }

    public void setTemplateId(String templateId) {
        this.templateId = templateId;
    }

    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public Long getAdStyleId() {
        return adStyleId;
    }

    public void setAdStyleId(Long adStyleId) {
        this.adStyleId = adStyleId;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getWidth() {
        return width;
    }

    public void setWidth(Integer width) {
        this.width = width;
    }

    public Integer getHeight() {
        return height;
    }

    public void setHeight(Integer height) {
        this.height = height;
    }

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getFormat() {
        return format;
    }

    public void setFormat(String format) {
        this.format = format;
    }

    public Integer getDuration() {
        return duration;
    }

    public void setDuration(Integer duration) {
        this.duration = duration;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> activity-center-api-0.10.34sjq-20200117.004702-3-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/AdvertisingSpaceStyleDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.List;

/**
 * @author shenjiaqing
 * @description
 * @data 2019/11/20
 */
public class AdvertisingSpaceStyleDto implements Serializable {

    /** 样式ID **/
    private Long id;

    /** 广告位类型ID **/
    private Long adTypeId;

    /** 样式名称 **/
    private String adStyleName;

    /** 最少标题字数 **/
    private Integer titleMinNum;

    /** 最多标题字数 **/
    private Integer titleMaxNum;

    /** 最少描述字数 **/
    private Integer descriptionMinNum;

    /** 最多描述字数 **/
    private Integer descriptionMaxNum;

    /** ADX样式ID **/
    private String templateId;

    /** 素材数量 **/
    private Integer num;

    /** 创建时间 **/
    private String createTime;

    /** 修改时间 **/
    private String modifyTime;

    /** 素材ID **/
    private Long materialId;

    /** 广告位样式ID **/
    private Long adStyleId;

    /** 素材类型 **/
    private Integer type;

    /** 素材宽度 **/
    private Integer width;

    /** 素材高度 **/
    private Integer height;

    /** 素材大小 **/
    private Integer size;

    /** 素材单位 **/
    private String unit;

    /** 素材格式 **/
    private String format;

    /** 视频时长 **/
    private Integer duration;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdTypeId() {
        return adTypeId;
    }

    public void setAdTypeId(Long adTypeId) {
        this.adTypeId = adTypeId;
    }

    public String getAdStyleName() {
        return adStyleName;
    }

    public void setAdStyleName(String adStyleName) {
        this.adStyleName = adStyleName;
    }

    public Integer getTitleMinNum() {
        return titleMinNum;
    }

    public void setTitleMinNum(Integer titleMinNum) {
        this.titleMinNum = titleMinNum;
    }

    public Integer getTitleMaxNum() {
        return titleMaxNum;
    }

    public void setTitleMaxNum(Integer titleMaxNum) {
        this.titleMaxNum = titleMaxNum;
    }

    public Integer getDescriptionMinNum() {
        return descriptionMinNum;
    }

    public void setDescriptionMinNum(Integer descriptionMinNum) {
        this.descriptionMinNum = descriptionMinNum;
    }

    public Integer getDescriptionMaxNum() {
        return descriptionMaxNum;
    }

    public void setDescriptionMaxNum(Integer descriptionMaxNum) {
        this.descriptionMaxNum = descriptionMaxNum;
    }

    public String getTemplateId() {
        return templateId;
    }

    public void setTemplateId(String templateId) {
        this.templateId = templateId;
    }

    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(String modifyTime) {
        this.modifyTime = modifyTime;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public Long getAdStyleId() {
        return adStyleId;
    }

    public void setAdStyleId(Long adStyleId) {
        this.adStyleId = adStyleId;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getWidth() {
        return width;
    }

    public void setWidth(Integer width) {
        this.width = width;
    }

    public Integer getHeight() {
        return height;
    }

    public void setHeight(Integer height) {
        this.height = height;
    }

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getFormat() {
        return format;
    }

    public void setFormat(String format) {
        this.format = format;
    }

    public Integer getDuration() {
        return duration;
    }

    public void setDuration(Integer duration) {
        this.duration = duration;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
